﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using Atlas.Models;
using Atlas.Models.Service;
using Atlas.Models.DAO;
using Atlas.Logger;
using Atlas.Consts;

namespace Atlas.Helpers.Service
{
    public class DeviceHelper
    {
        private static Atlas.Models.Service.Device ConvertObjectToDevice(Atlas.Models.Object sqlObject)
        {
            try
            {
                if (sqlObject == null)
                {
                    return null;
                }   //if
                Atlas.Models.Service.Device device = new Atlas.Models.Service.Device();
                device.deviceId = sqlObject.ObjectId.ToString();
                device.deviceName = sqlObject.Number;
                return device;
            }   //try
            catch (Exception ex)
            {
                MyLogger.Log(ex);
                return null;
            }   //catch
        }

        public static List<Atlas.Models.Service.Device> GetDevices(string userName, int clientId)
        {
            try
            {
                List<Atlas.Models.Service.Device> devices = new List<Atlas.Models.Service.Device>();
                if (String.IsNullOrEmpty(userName))
                {
                    MyLogger.Log("Cannot get devices - empty userName", MyLogger.LogLevel.Error);
                    return devices;
                }   //if
                Login login = AuthHelper.GetLoginObject(userName, clientId);
                if (login == null)
                {
                    MyLogger.Log(String.Format("Cannot get devices - login object null for userName - {0}, clientId - {1}", userName, clientId), MyLogger.LogLevel.Error);
                    return devices;
                }   //if
                ObjectDAO objectDAO = new ObjectDAO();
                List<Atlas.Models.Object> objects = null;
                if ((login.RoleId == GlobalConsts.ROLE_ID_ADMIN) || (login.RoleId == GlobalConsts.ROLE_ID_POWER_USER))
                {
                    objects = objectDAO.GetObjectsForClient(clientId);
                }   //if
                else if (login.RoleId == GlobalConsts.ROLE_ID_USER)
                {
                    objects = objectDAO.GetObjectsForClient(clientId, login.LoginId);
                }   //else
                if (objects == null)
                {
                    MyLogger.Log(String.Format("Cannot get devices - objects list null for loginId - {0}, clientId - {1}", login.LoginId, clientId), MyLogger.LogLevel.Error);
                    return devices;
                }   //if
                foreach (Atlas.Models.Object sqlObject in objects)
                {
                    Atlas.Models.Service.Device device = DeviceHelper.ConvertObjectToDevice(sqlObject);
                    if (device != null)
                    {
                        devices.Add(device);
                    }   //if
                }   //for
                return devices;
            }
            catch (Exception ex)
            {
                MyLogger.Log(ex);
            }   //catch
            return null;
        }

        public static Atlas.Models.Service.Device GetDevice(int deviceId)
        {
            try
            {
                ObjectDAO objectDAO = new ObjectDAO();
                Atlas.Models.Object sqlObject = objectDAO.FindByPK(deviceId);
                if (sqlObject == null)
                {
                    return null;
                }   //if
                return DeviceHelper.ConvertObjectToDevice(sqlObject);
            }
            catch (Exception ex)
            {
                MyLogger.Log(ex);
            }   //catch
            return null;
        }

    }
}
