﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using Atlas.Models;
using Atlas.Models.Service;
using Atlas.Models.Service.Db;
using Atlas.Models.DAO;
using Atlas.Logger;
using Atlas.Consts;

namespace Atlas.Helpers.Service
{
    public class EventsHelper
    {
        private static DeviceEvent ConvertSqlDataToEvent(DeviceEventFromDb eventFromDb)
        {
            if (eventFromDb == null)
            {
                return null;
            }   //if
            try
            {
                if ((eventFromDb.x == null) || (eventFromDb.y == null) || (eventFromDb.gpsTime == null))
                {
                    return null;
                }   //if
                DeviceEvent deviceEvent = new DeviceEvent();
                deviceEvent.coordinate = new Coordinate(eventFromDb.x.Value, eventFromDb.y.Value);
                deviceEvent.gpsTime = GlobalHelper.ConvertToTimestamp(eventFromDb.gpsTime.Value);
                deviceEvent.zaplonValue = eventFromDb.zaplon;
                deviceEvent.zbiornik1Value = eventFromDb.zbiornik1;
                deviceEvent.zbiornik2Value = eventFromDb.zbiornik2;
                return deviceEvent;
            }   //try
            catch (Exception ex)
            {
                MyLogger.Log(ex);
            }   //catch
            return null;
        }

        private static SimpleDeviceEvent ConvertSqlDataToEvent(SimpleDeviceEventFromDb eventFromDb)
        {
            if (eventFromDb == null)
            {
                return null;
            }   //if
            try
            {
                if ((eventFromDb.x == null) || (eventFromDb.y == null) || (eventFromDb.gpsTime == null))
                {
                    return null;
                }   //if
                SimpleDeviceEvent deviceEvent = new SimpleDeviceEvent();
                deviceEvent.coordinate = new Coordinate(eventFromDb.x.Value, eventFromDb.y.Value);
                deviceEvent.gpsTime = GlobalHelper.ConvertToTimestamp(eventFromDb.gpsTime.Value);
                deviceEvent.zaplonValue = eventFromDb.zaplon;
                return deviceEvent;
            }   //try
            catch (Exception ex)
            {
                MyLogger.Log(ex);
            }   //catch
            return null;
        }

        public static List<DeviceEvent> GetEvents(long deviceId, int year, int month, int day)
        {
            try
            {
                List<DeviceEvent> events = new List<DeviceEvent>();
                MessagesDAO messageDAO = new MessagesDAO();
                IEnumerable<DeviceEventFromDb> eventsFromDbEnum = messageDAO.FindEventsByDeviceIdAndDate(deviceId, year, month, day);
                if (eventsFromDbEnum == null)
                {
                    return events;
                }   //if
                List<DeviceEventFromDb> eventsFromDb = eventsFromDbEnum.ToList();
                if (eventsFromDb.Count() == 0)
                {
                    return events;
                }   //if
                foreach (DeviceEventFromDb eventFromDb in eventsFromDb)
                {
                    DeviceEvent deviceEvent = EventsHelper.ConvertSqlDataToEvent(eventFromDb);
                    if (eventFromDb != null)
                    {
                        events.Add(deviceEvent);
                    }   //if
                }   //for
                return events;
            }   //try
            catch (Exception ex)
            {
                MyLogger.Log(ex);
                return null;
            }   //catch
        }

        public static List<SimpleDeviceEvent> GetSimpleEvents(long deviceId, int year, int month, int day)
        {
            try
            {
                List<SimpleDeviceEvent> events = new List<SimpleDeviceEvent>();
                MessagesDAO messageDAO = new MessagesDAO();
                IEnumerable<SimpleDeviceEventFromDb> eventsFromDbEnum = messageDAO.FindSimpleEventsByDeviceIdAndDate(deviceId, year, month, day);
                if (eventsFromDbEnum == null)
                {
                    return events;
                }   //if
                List<SimpleDeviceEventFromDb> eventsFromDb = eventsFromDbEnum.ToList();
                if (eventsFromDb.Count() == 0)
                {
                    return events;
                }   //if
                foreach (SimpleDeviceEventFromDb eventFromDb in eventsFromDb)
                {
                    SimpleDeviceEvent deviceEvent = EventsHelper.ConvertSqlDataToEvent(eventFromDb);
                    if (eventFromDb != null)
                    {
                        events.Add(deviceEvent);
                    }   //if
                }   //for
                return events;
            }   //try
            catch (Exception ex)
            {
                MyLogger.Log(ex);
                return null;
            }   //catch
        }

        public static double GetDistanceForDevice(int deviceId, long timestampFrom, long timestampTo)
        {
            try
            {
                TripStopDAO tripStopDAO = new TripStopDAO();
                return tripStopDAO.GetGpsDistance(deviceId, GlobalHelper.ConvertToDateTime(timestampFrom), GlobalHelper.ConvertToDateTime(timestampTo));
            }   //try
            catch (Exception ex)
            {
                MyLogger.Log(ex);
                return 0;
            }   //catch
        }

    }
}
