﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using Atlas.Consts;
using System.Xml.Serialization;
using System.IO;
using Atlas.Logger;
using Atlas.Models.Service;

namespace Atlas.Helpers
{
    public class UsersXmlHelper
    {

        private static string GetUsersXmlPath(string fileName)
        {
            if (String.IsNullOrEmpty(fileName))
            {
                fileName = GlobalConsts.DEFAULT_USERS_XML_FILE;
            }   //if
            HttpServerUtility httpServer = HttpObjectsHelper.GetHttpServer();
            if (httpServer == null)
            {
                return String.Empty;
            }   //if
            return Path.Combine(httpServer.MapPath(GlobalConsts.DEFAULT_USERS_ABSOLUTE_DIR), fileName);
        }

        private static users GetUsersXmlObject(String fileName)
        {
            try
            {
                XmlSerializer serializer = new XmlSerializer(typeof(users));
                string usersFile = UsersXmlHelper.GetUsersXmlPath(fileName);
                if (String.IsNullOrEmpty(usersFile))
                {
                    return null;
                }   //if
                if (!File.Exists(usersFile))
                {
                    return null;
                }   //if
                TextReader reader = new StreamReader(usersFile);
                try
                {
                    return (users)serializer.Deserialize(reader);
                }   //try
                finally
                {
                    reader.Close();
                }   //finally
            }   //try
            catch (Exception ex)
            {
                MyLogger.Log(ex);
                MyLogger.Log(ex.GetBaseException());
                return null;
            }   //catch
        }

        public static List<UserXml> GetUsers()
        {
            List<UserXml> users = new List<UserXml>();
            try
            {
                users usersXmlObject = UsersXmlHelper.GetUsersXmlObject(String.Empty);
                usersUser[] usersXml = usersXmlObject.Items;
                if (usersXml == null)
                {
                    return users;
                }   //if
                foreach (usersUser userXml in usersXml)
                {
                    UserXml userToReturn = new UserXml();
                    if ((String.IsNullOrEmpty(userXml.client)) 
                        || (String.IsNullOrEmpty(userXml.login)) 
                        || (String.IsNullOrEmpty(userXml.pass)))
                    {
                        continue;
                    }   //if
                    userToReturn.client = userXml.client;
                    userToReturn.login = userXml.login;
                    userToReturn.pass = userXml.pass;
                    users.Add(userToReturn);
                }   //for
                return users;
            }   //try
            catch (Exception ex)
            {
                MyLogger.Log(ex);
                MyLogger.Log(ex.GetBaseException());
                return users;
            }   //catch            
        }
    }
}
