﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using Atlas.Models.DAO.Abstracts;
using Atlas.Logger;
using Atlas.Models.Service;
using Atlas.Models.Service.Db;
using Atlas.Helpers;

namespace Atlas.Models.DAO
{
    public class MessagesDAO : AbstractGenericDAO<Message, long>
    {
        protected override string GetKeyProperty()
        {
            return "MessageId";
        }

        public List<Message> GetLastMessagesForClient(int clientId)
        {
            try
            {
                IQueryable<fn_LastClientMessagesResult> lastMessages = 
                    (from l in this._entitiesDataContext.fn_LastClientMessages(clientId) select l);
                if (lastMessages == null)
                {
                    return null;
                }   //if
                List<Message> messages = new List<Message>();
                foreach (fn_LastClientMessagesResult lastMessage in lastMessages)
                {
                    Message message = this.FindByPK(lastMessage.MessageId);
                    if (message != null)
                    {
                        messages.Add(message);
                    }   //if
                }   //for
                return messages;
            }   //try
            catch (Exception ex)
            {
                MyLogger.Log(ex);
            }   //catch
            return null;
        }

        public Message GetLastMessageForClientAndObject(int clientId, int objectId)
        {
            try
            {
                IQueryable<Message> messages = (from m in this._entitiesDataContext.Messages
                              where m.ObjectId == objectId 
                                && this._entitiesDataContext.fn_LastClientMessages(clientId).Any((lcm) => (lcm.MessageId == m.MessageId))
                              select m);
                if (messages == null)
                {
                    return null;
                }   //if
                foreach (Message message in messages)
                {
                    return message;
                }   //for
            }   //try
            catch (Exception ex)
            {
                MyLogger.Log(ex);
            }   //catch
            return null;
        }

        public IQueryable<MessageData> FindDataByMessageId(long messageId)
        {
            try
            {
                return (from md in this._entitiesDataContext.MessageDatas
                              where md.MessageId == messageId
                              select md);
            }
            catch (Exception ex)
            {
                MyLogger.Log(ex);
            }   //catch
            return null;
        }

        public IEnumerable<DeviceEventFromDb> FindEventsByDeviceIdAndDate(long deviceId, int year, int month, int day)
        {
            try
            {
                return this._entitiesDataContext.ExecuteQuery<DeviceEventFromDb>(
                    "select DISTINCT Message.GpsTime, " +
                    "MAX(CASE WHEN DataSource.Name = 'Zbiornik1' THEN MessageData.Value END) AS 'zbiornik1', " +
                    "MAX(CASE WHEN DataSource.Name = 'Zbiornik2' THEN MessageData.Value END) AS 'zbiornik2', " +
                    "MAX(CASE WHEN DataSource.Name LIKE 'Zap_on' THEN MessageData.Value END) AS 'zaplon', " +
                    "Message.X, Message.Y " +
                    "from tavl.Message " +
                    "inner join tavl.MessageData on (tavl.Message.MessageId = tavl.MessageData.MessageId) " +
                    "inner join tavl.DataSource on (tavl.DataSource.DataSourceId = tavl.MessageData.DataSourceId) " +
                    "where tavl.Message.ObjectId = {0} " +
                    "and day(message.GpsTime) = {1} " +
                    "and month(message.GpsTime) = {2} " +
                    "and year(message.GpsTime) = {3} " +
                    "group by message.GpsTime, Message.X, Message.Y " +
                    "order by 1", deviceId, day, month, year
                );
            }
            catch (Exception ex)
            {
                MyLogger.Log(ex);
            }   //catch
            return null;
        }

        public IEnumerable<SimpleDeviceEventFromDb> FindSimpleEventsByDeviceIdAndDate(long deviceId, int year, int month, int day)
        {            
            try
            {
                return this._entitiesDataContext.ExecuteQuery<SimpleDeviceEventFromDb>(
                    "select DISTINCT Message.GpsTime, " +
                    "MAX(CASE WHEN DataSource.Name LIKE 'Zap_on' THEN MessageData.Value END) AS 'zaplon', " +
                    "Message.X, Message.Y " +
                    "from tavl.Message " +
                    "inner join tavl.MessageData on (tavl.Message.MessageId = tavl.MessageData.MessageId) " +
                    "inner join tavl.DataSource on (tavl.DataSource.DataSourceId = tavl.MessageData.DataSourceId) " +
                    "where tavl.Message.ObjectId = {0} " +
                    "and day(message.GpsTime) = {1} " +
                    "and month(message.GpsTime) = {2} " +
                    "and year(message.GpsTime) = {3} " +
                    "group by message.GpsTime, Message.X, Message.Y " +
                    "order by 1", deviceId, day, month, year
                );
            }
            catch (Exception ex)
            {
                MyLogger.Log(ex);
            }   //catch
            return null;
        }

    }
}
