﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using Atlas.Models.DAO.Abstracts;
using Atlas.Logger;
using Atlas.Consts;

namespace Atlas.Models.DAO
{
    public class ObjectDAO : AbstractGenericDAO<Object, int>
    {
        protected override string GetKeyProperty()
        {
            return "ObjectId";
        }

        public List<Object> GetObjectsForClient(int clientId, int loginId)
        {
            try
            {                
                IQueryable<fn_GroupObjectsResult> functionObjects = 
                    (from o in this._entitiesDataContext.fn_GroupObjects(clientId, GlobalConsts.ALL_GROUPED_OBJECTS, loginId)
                         select o);                
                List<Object> objects = this.GetObjectsListFromFunctionCollection(functionObjects);
                if (objects != null)
                {
                    if (objects.Count() > 0)
                    {
                        return objects;
                    }   //if
                }   //if
                functionObjects = 
                    (from o in this._entitiesDataContext.fn_GroupObjects(clientId, GlobalConsts.NON_GROUPED_OBJECTS, loginId)
                         select o);                
                return this.GetObjectsListFromFunctionCollection(functionObjects);
            }   //try
            catch (Exception ex)
            {
                MyLogger.Log(ex);
            }   //catch
            return null;
        }

        public List<Object> GetObjectsForClient(int clientId)
        {
            try
            {
                IQueryable<Object> functionObjects =
                    (from o in this._entitiesDataContext.Objects
                     where ((o.ClientId == clientId) && (o.Deleted == false))
                     select o);
                return this.GetObjectsListFromFunctionCollection(functionObjects);
            }   //try
            catch (Exception ex)
            {
                MyLogger.Log(ex);
            }   //catch
            return null;
        }

        private List<Object> GetObjectsListFromFunctionCollection(IQueryable<fn_GroupObjectsResult> functionObjects)
        {
            List<Object> objects = new List<Object>();
            if (functionObjects == null)
            {
                return null;
            }
            if (functionObjects.Count() == 0)
            {
                return null;
            }
            foreach (fn_GroupObjectsResult functionObject in functionObjects)
            {
                if (functionObject.ObjectId.HasValue)
                {
                    Object entity = this.FindByPK(functionObject.ObjectId.Value);
                    if (entity != null)
                    {
                        objects.Add(entity);
                    }   //if
                }   //if
            }   //for
            return objects;
        }

        private List<Object> GetObjectsListFromFunctionCollection(IQueryable<Object> functionObjects)
        {
            if (functionObjects == null)
            {
                return null;
            }
            if (functionObjects.Count() == 0)
            {
                return null;
            }
            return new List<Object>(functionObjects);
        }

    }
}
