﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using Atlas.Models.DAO.Abstracts;
using Atlas.Logger;
using Atlas.Consts;

namespace Atlas.Models.DAO
{
    public class TripStopDAO : AbstractGenericDAO<TripStop, int>
    {
        protected override string GetKeyProperty()
        {
            return "TripStopId";
        }

        public double GetGpsDistance(int objectId)
        {
            try
            {                
                double calculatedDistance = 
                    (from ts in this._entitiesDataContext.TripStops
                        where ts.ObjectId == objectId
                        select ts.GpsDistance).Sum();
                if (calculatedDistance == null)
                {
                    calculatedDistance = 0;
                }   //if
                return calculatedDistance;
            }   //try
            catch (Exception ex)
            {
                MyLogger.Log(ex);
            }   //catch
            return 0;
        }

        public double GetGpsDistance(int deviceId, DateTime timeFrom, DateTime timeTo)
        {
            try
            {
                IEnumerable<double> results = this._entitiesDataContext.ExecuteQuery<double>(
                    "select tavl.fn_GpsCalculatedDistance({0}, {1}, {2}, 5, null)",
                    deviceId, timeFrom, timeTo
                );
                if (results == null)
                {
                    return 0;
                }   //if
                List<double> resultList = results.ToList();
                if (resultList.Count() == 0)
                {
                    return 0;
                }   //if
                return resultList.First();
            }
            catch (Exception ex)
            {
                MyLogger.Log(ex);
            }   //catch
            return 0;
        }

    }
}
